@@ -20,4 +20,9 @@
   # Fit Least Angle Regression to Uncorrelated Components (closed form)...
   rxuobj <- RXuclars(form, data=longley2)
   rxuobj
-  plot(rxuobj)
\ No newline at end of file
+  plot(rxuobj)
+  cat("\n Press ENTER for RXsigns output on Correction of WRONG-SIGNs...")
+  scan()
+  # Show Coefficients with Minimum MSE Risk Parallel to unknown, true Beta...
+  rxsobj <- RXsigns(form, data=longley2)
+  rxsobj
\ No newline at end of file
